"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isIgnoredPath = void 0;
// builtin
const path_1 = require("path");
// external
const ignorepatterns_1 = __importDefault(require("ignorepatterns"));
/** Tests the path against provided prefixes and regular expressions */
function matches(path, matches) {
    for (const match of matches) {
        if (typeof match === 'string') {
            if (path.startsWith(match))
                return true;
        }
        else if (match.test(path))
            return true;
    }
    return false;
}
/** Tests whether the path should be ignored */
function isIgnoredPath(path, opts = {
    ignoreCommonPatterns: true,
}) {
    // handle deprecations
    opts = {
        ignoreHiddenBasenames: opts.ignoreHiddenFiles,
        ignoreUndesiredBasenames: opts.ignoreCommonPatterns,
        ...opts,
        ignoreAbsolutePaths: [
            ...(opts.ignoreAbsolutePaths || []),
            ...(opts.ignorePaths || []),
        ],
        ignoreRelativePaths: [
            ...(opts.ignoreRelativePaths || []),
            ...(opts.ignorePaths || []),
        ],
        ignoreBasenames: [
            ...(opts.ignoreBasenames || []),
            ...(opts.ignorePaths || []),
        ],
    };
    // extract path, fallback basename, and reconstruct path with its custom properties if any (helpful for scandirectory)
    const { absolutePath, relativePath } = path;
    let { basename } = path;
    if (!basename && (absolutePath || relativePath))
        basename = (0, path_1.basename)(absolutePath || relativePath || '');
    path = { ...path, basename };
    // custom callback
    if (opts.ignoreCustomCallback && opts.ignoreCustomCallback(path) === true)
        return true;
    // absolute path checks
    if (absolutePath) {
        // match
        if (opts.ignoreAbsolutePaths?.length &&
            matches(absolutePath, opts.ignoreAbsolutePaths))
            return true;
        // custom?
        if (opts.ignoreCustomPatterns &&
            opts.ignoreCustomPatterns.test(absolutePath))
            return true;
    }
    // relative path checks
    if (relativePath) {
        // match
        if (opts.ignoreRelativePaths?.length &&
            matches(relativePath, opts.ignoreRelativePaths))
            return true;
        // custom?
        if (opts.ignoreCustomPatterns &&
            opts.ignoreCustomPatterns.test(relativePath))
            return true;
    }
    // basename checks
    if (basename) {
        // match
        if (opts.ignoreBasenames?.length && matches(basename, opts.ignoreBasenames))
            return true;
        // hidden?
        if (opts.ignoreHiddenBasenames && basename[0] === '.')
            return true;
        // common?
        if (opts.ignoreUndesiredBasenames &&
            ignorepatterns_1.default.test(basename))
            return true;
        // custom?
        if (opts.ignoreCustomPatterns && opts.ignoreCustomPatterns.test(basename))
            return true;
    }
    // not ignored
    return false;
}
exports.isIgnoredPath = isIgnoredPath;
/** Compatibility wrapper for {@link isIgnoredPath} */
function isIgnoredPathCompatibility(path, opts) {
    if (typeof path === 'string') {
        const result = {};
        if ((0, path_1.isAbsolute)(path))
            result.absolutePath = path;
        else
            result.relativePath = path;
        result.basename = (0, path_1.basename)(path);
        return isIgnoredPath(result, opts);
    }
    else {
        return isIgnoredPath(path, opts);
    }
}
exports.default = isIgnoredPathCompatibility;
