/** A path to check its ignore status */
export interface Path {
    /** The absolute path, if any */
    absolutePath?: string;
    /** The relative path, if any */
    relativePath?: string;
    /** If not provided, will be determined from {@link absolutePath}/{@link relativePath} */
    basename?: string;
}
/** Ignore Options */
export interface Options {
    /** Absolute paths to ignore */
    ignoreAbsolutePaths?: Array<string | RegExp>;
    /** Relative paths to ignore */
    ignoreRelativePaths?: Array<string | RegExp>;
    /** Basenames to ignore */
    ignoreBasenames?: Array<string | RegExp>;
    /** @deprecated alias for {@link ignoreAbsolutePaths}, {@link ignoreRelativePaths}, and {@link ignoreBasenames} */
    ignorePaths?: Array<string | RegExp>;
    /** Ignore basenames that begin with a `.` character */
    ignoreHiddenBasenames?: boolean;
    /** @deprecated alias for {@link Options.ignoreHiddenBasenames} */
    ignoreHiddenFiles?: boolean;
    /** Ignore commonly undesirable basenames: https://github.com/bevry/ignorepatterns */
    ignoreUndesiredBasenames?: boolean;
    /** @deprecated alias for {@link Options.ignoreUndesiredBasenames} */
    ignoreCommonPatterns?: boolean;
    /** Test against each {@link Path} property */
    ignoreCustomPatterns?: RegExp;
    /** Your own ignore handler */
    ignoreCustomCallback?: (path: Path) => boolean | void;
}
/** Tests whether the path should be ignored */
export declare function isIgnoredPath(path: Path, opts?: Options): boolean;
/** Compatibility wrapper for {@link isIgnoredPath} */
export default function isIgnoredPathCompatibility(path: Path | string, opts?: Options): boolean;
//# sourceMappingURL=index.d.ts.map